{#-
  This file was automatically generated - do not edit
-#}
{% extends "base.html" %}
{% block extrahead %}
  {% set title = config.site_name %}
  {% if page and page.title and not page.is_homepage %}
    {% set title = config.site_name ~ " - " ~ page.title | striptags %}
  {% endif %}
  {% set image = config.site_url ~ 'assets/images/banner.png' %}
  <meta property="og:type" content="website">
  <meta property="og:title" content="{{ title }}">
  <meta property="og:description" content="{{ config.site_description }}">
  <meta property="og:url" content="{{ page.canonical_url }}">
  <meta property="og:image" content="{{ image }}">
  <meta property="og:image:type" content="image/png">
  <meta property="og:image:width" content="1200">
  <meta property="og:image:height" content="630">
  <meta name="twitter:card" content="summary_large_image">
  <meta name="twitter:site" content="@squidfunk">
  <meta name="twitter:creator" content="@squidfunk">
  <meta name="twitter:title" content="{{ title }}">
  <meta name="twitter:description" content="{{ config.site_description }}">
  <meta name="twitter:image" content="{{ image }}">
{% endblock %}
{% block announce %}
  <style>.md-announce{transition:background-color 125ms}.md-announce:focus-within{background-color:var(--md-accent-fg-color)}.md-announce a,.md-announce a:focus,.md-announce a:hover{color:currentColor}.md-announce strong{white-space:nowrap}</style>
  <a href="https://ginseng.ai/blog/the-cognitive-complexity-of-css/">
    Check out <strong>squidfunk</strong>'s latest blog post –
    <strong>
      The Cognitive Complexity of CSS
    </strong>
  </a>
{% endblock %}
