{#-
  This file was automatically generated - do not edit
-#}
{% set class = "md-hero" %}
{% if "tabs" not in config.theme.features %}
  {% set class = "md-hero md-hero--expand" %}
{% endif %}
<div class="{{ class }}" data-md-component="hero">
  <div class="md-hero__inner md-grid">
    {{ page.meta.hero }}
  </div>
</div>
